Learn R Programming

rcolors (version 0.1.0)

get_color: Get and interpolate colors

Description

Get and interpolate colors

Usage

get_color(col, n = NULL, show = FALSE)

Arguments

col

color name in the rcolors or a vector of colors

n

Integer, default is length of col

show

Boolean, whether to visualize those colors?

Value

A character vector with elements of 7 or 9 characters, "#" followed by the red, blue, green and optionally alpha values in hexadecimal (after rescaling to 0 ... 255). The optional alpha values range from 0 (fully transparent) to 255 (opaque).

R does not use ‘premultiplied alpha’.

Details

supported col names: 270 ncl colors (names(rcolors)) and 35 RColorBrewer colors (names(colors_group$brewer)).

See Also

show_cols()

Examples

Run this code
# NOT RUN {
print(names(rcolors[1:6]))
print(names(colors_group$brewer))
get_color("amwg_blueyellowred", n = 20)
# }

Run the code above in your browser using DataLab