powered by
Show list of colors
show_cols: show list of colors
show_cols
show_cols_brewer: show list of colors in RColorBrewer style
show_cols_brewer
show_cols(colors_list, margin = 8, fontsize = 1, family = NULL)show_cols_brewer(colors_list)show_col(colors, labels = TRUE, borders = NULL, cex_label = 1, nrow = NULL)
show_cols_brewer(colors_list)
show_col(colors, labels = TRUE, borders = NULL, cex_label = 1, nrow = NULL)
A list objects filled with colors_list or a color vector
margin in the left
font family and size of color names in the left
a character vector of colors
boolean, whether to show the hexadecimal representation of the colours in each tile
colour of the borders of the tiles
size of printed labels, works the same as cex parameter of plot()
plot()
integer, number of rows
# NOT RUN { print(names(colors_group)) show_cols(colors_group$rainbow, margin = 14) # }
Run the code above in your browser using DataLab